@@ -61,17 +61,6 @@ int attribs_encode(struct sbuf *sb)
 	p=sb->attr.buf;
 	statp=&sb->statp;
 
-	if(sb->protocol2)
-	{
-		// Protocol1 does not have this field.
-		p += to_base64(sb->protocol2->index, p);
-		*p++ = ' ';
-		// Protocol2 puts compression/encryption near the beginning.
-		p += to_base64(sb->compression, p);
-		*p++ = ' ';
-		p += to_base64(sb->encryption, p);
-		*p++ = ' ';
-	}
 	p += to_base64(statp->st_dev, p);
 	*p++ = ' ';
 	p += to_base64(statp->st_ino, p);
@@ -115,17 +104,15 @@ int attribs_encode(struct sbuf *sb)
 
 	p += to_base64(sb->winattr, p);
 
-	if(sb->protocol1)
-	{
-		// Protocol1 puts compression/encryption at the end.
-		*p++ = ' ';
-		p += to_base64(sb->compression, p);
-		*p++ = ' ';
-		p += to_base64(sb->encryption, p);
-		*p++ = ' ';
-		p += to_base64(sb->protocol1->salt, p);
-	}
-
+	*p++ = ' ';
+	p += to_base64(sb->compression, p);
+	*p++ = ' ';
+	p += to_base64(sb->encryption, p);
+	*p++ = ' ';
+	p += to_base64(sb->salt, p);
+	*p++ = ' ';
+	// 0 means winapi is enabled, 1 means it is disabled.
+	p += to_base64(!sb->use_winapi, p);
 	*p = 0;
 
 	sb->attr.len=p-sb->attr.buf;
@@ -147,32 +134,6 @@ void attribs_decode(struct sbuf *sb)
 	if(!(p=sb->attr.buf)) return;
 	statp=&sb->statp;
 
-	if(sb->protocol2)
-	{
-		// In protocol2, the first component (index) sometimes gets
-		// stripped off of the attributes, so look out for that.
-		if(*p!=' ')
-		{
-			// Protocol1 does not have this field.
-			if(!(eaten=from_base64(&val, p)))
-				return;
-			p+=eaten;
-			sb->protocol2->index=val;
-		}
-
-		// Compression for protocol2.
-		if(!(eaten=from_base64(&val, p)))
-			return;
-		p+=eaten;
-		sb->compression=val;
-
-		// Encryption for protocol2.
-		if(!(eaten=from_base64(&val, p)))
-			return;
-		p+=eaten;
-		sb->encryption=val;
-	}
-
 	if(!(eaten=from_base64(&val, p)))
 		return;
 	p+=eaten;
@@ -263,29 +224,29 @@ void attribs_decode(struct sbuf *sb)
 	p+=eaten;
 	sb->winattr=val;
 
-	if(sb->protocol1)
-	{
-		sb->compression=-1;
-		sb->encryption=ENCRYPTION_UNSET;
+	sb->compression=-1;
+	sb->encryption=ENCRYPTION_UNSET;
 
-		// Compression for protocol1.
-		if(!(eaten=from_base64(&val, p)))
-			return;
-		p+=eaten;
-		sb->compression=val;
+	if(!(eaten=from_base64(&val, p)))
+		return;
+	p+=eaten;
+	sb->compression=val;
 
-		// Encryption for protocol1.
-		if(!(eaten=from_base64(&val, p)))
-			return;
-		p+=eaten;
-		sb->encryption=val;
+	if(!(eaten=from_base64(&val, p)))
+		return;
+	p+=eaten;
+	sb->encryption=val;
 
-		// Salt for protocol1.
-		if(!(eaten=from_base64(&val, p)))
-			return;
-		p+=eaten;
-		sb->protocol1->salt=val;
-	}
+	if(!(eaten=from_base64(&val, p)))
+		return;
+	p+=eaten;
+	sb->salt=val;
+
+	if(!(eaten=from_base64(&val, p)))
+		return;
+	p+=eaten;
+	// 0 means winapi is enabled, 1 means it is disabled.
+	sb->use_winapi=!val;
 }
 
 int attribs_set_file_times(struct asfd *asfd,
@@ -353,8 +314,7 @@ int attribs_set(struct asfd *asfd, const char *path,
 	win32_chmod(path, statp->st_mode, winattr);
 	attribs_set_file_times(asfd, path, statp, cntr);
 	return 0;
-#endif
-
+#else
 	if(lchown(path, statp->st_uid, statp->st_gid)<0)
 	{
 		struct berrno be;
@@ -427,4 +387,5 @@ int attribs_set(struct asfd *asfd, const char *path,
 	}
 
 	return 0;
+#endif
 }
