@@ -7,13 +7,12 @@
 #include "fsops.h"
 #include "fzp.h"
 #include "handy.h"
+#include "handy_extra.h"
 #include "hexmap.h"
 #include "iobuf.h"
 #include "log.h"
 #include "msg.h"
 #include "prepend.h"
-#include "protocol1/handy.h"
-#include "protocol2/blk.h"
 
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -463,7 +462,7 @@ err:
 }
 
 // Not in dpth.c so that Windows client can see it.
-int dpth_protocol1_is_compressed(int compressed, const char *datapath)
+int dpth_is_compressed(int compressed, const char *datapath)
 {
 	const char *dp=NULL;
 
@@ -510,7 +509,7 @@ int receive_a_file(struct asfd *asfd, const char *path, struct cntr *cntr)
 	uint64_t sentbytes=0;
 
 	if(!(bfd=bfile_alloc())) goto end;
-	bfile_init(bfd, 0, cntr);
+	bfile_init(bfd, 0, 0, cntr);
 #ifdef HAVE_WIN32
 	bfd->set_win32_api(bfd, 0);
 #else
