@@ -34,7 +34,7 @@ extern int set_keepalive(int fd, int value);
 extern int init_client_socket(const char *host, const char *port);
 extern void reuseaddr(int fd);
 extern int chuser_and_or_chgrp(const char *user, const char *group, int readall);
-extern int dpth_protocol1_is_compressed(int compressed, const char *datapath);
+extern int dpth_is_compressed(int compressed, const char *datapath);
 #ifndef HAVE_WIN32
 extern void setup_signal(int sig, void handler(int sig));
 #endif
