@@ -87,9 +87,6 @@ void Win32ConvCleanupCache(void)
 	g_dwWin32ConvUTF8strlen=0;
 }
 
-//#define USE_WIN32_COMPAT_IO 1
-#define USE_WIN32_32KPATHCONVERSION 1
-
 extern DWORD g_platform_id;
 extern DWORD g_MinorVersion;
 
@@ -98,8 +95,11 @@ extern DWORD g_MinorVersion;
 
 #define WIN32_FILETIME_SCALE 10000000 // 100ns/second
 
-void conv_unix_to_win32_path(const char *name, char *win32_name, DWORD dwSize)
-{
+static void conv_unix_to_win32_path(
+	const char *name,
+	char *win32_name,
+	DWORD dwSize
+) {
 	char *tname=win32_name;
 	const char *fname=name;
 
@@ -163,35 +163,13 @@ void conv_unix_to_win32_path(const char *name, char *win32_name, DWORD dwSize)
 	}
 }
 
-// Conversion of a Unix filename to a Win32 filename.
-char *unix_name_to_win32(char *name)
-{
-	char *ret=NULL;
-	char *tmp=NULL;
-
-	// One extra byte should suffice, but we double it.
-	// Add MAX_PATH bytes for VSS shadow copy name.
-	DWORD dwSize=2*strlen(name)+MAX_PATH;
-	tmp=sm_get_pool_memory();
-	tmp=sm_check_pool_memory_size(tmp, dwSize);
-	conv_unix_to_win32_path(name, tmp, dwSize);
-	if(tmp) ret=strdup(tmp);
-	sm_free_pool_memory(tmp);
-	return ret;
-}
-
 /* Created 02/27/2006 Thorsten Engel.
    This function expects an UCS-encoded standard wchar_t in pszUCSPath and
-   will complete the input path to an absolue path of the form \\?\c:\path\file
+   will complete the input path to an absolute path of the form \\?\c:\path\file
 
    With this trick, it is possible to have 32K characters long paths.
-
-   Optionally one can use pBIsRawPath to determine id pszUCSPath contains a
-   path to a raw windows partition. */
-char *make_wchar_win32_path(char *pszUCSPath, BOOL *pBIsRawPath)
-{
-	if(pBIsRawPath) *pBIsRawPath=FALSE;
-
+*/
+static char *make_wchar_win32_path(char *pszUCSPath) {
 	if(!p_GetCurrentDirectoryW) return pszUCSPath;
 
 	wchar_t *name=(wchar_t *)pszUCSPath;
@@ -239,7 +217,6 @@ char *make_wchar_win32_path(char *pszUCSPath, BOOL *pBIsRawPath)
 		bAddDrive=FALSE;
 		bAddCurrentPath=FALSE;
 		bAddPrefix=FALSE;
-		if(pBIsRawPath) *pBIsRawPath=TRUE;
 	}
 
 	int nParseOffset=0;
@@ -385,7 +362,7 @@ int wchar_2_UTF8(char *pszUTF, const wchar_t *pszUCS, int cchChar)
 /* The return value is the number of wide characters written to the buffer.
    Convert null terminated string from utf-8 to ucs2, enlarge buffer if
    necessary. */
-int UTF8_2_wchar(char **ppszUCS, const char *pszUTF)
+static int UTF8_2_wchar(char **ppszUCS, const char *pszUTF)
 {
 	int ret=0;
 	DWORD cchSize;
@@ -401,30 +378,6 @@ int UTF8_2_wchar(char **ppszUCS, const char *pszUTF)
 	return ret;
 }
 
-void wchar_win32_path(const char *name, wchar_t *win32_name)
-{
-	const char *fname=name;
-	while(*name)
-	{
-		// Check for Unix separator and convert to Win32.
-		if(*name=='/')
-			*win32_name++='\\';
-		else if(*name=='\\' && name[1]=='\\')
-		{
-			*win32_name++='\\';
-			name++;
-		}
-		else
-			*win32_name++=*name;
-		name++;
-	}
-	// Strip any trailing slash, if we stored something.
-	if(*fname && win32_name[-1]=='\\')
-		win32_name[-1]=0;
-	else
-		*win32_name=0;
-}
-
 // Allows one or both pointers to be NULL
 static bool bstrcmp(const char *s1, const char *s2)
 {
@@ -436,10 +389,9 @@ static bool bstrcmp(const char *s1, const char *s2)
 /* If we find the utf8 string in cache, we use the cached ucs2 version.
    We compare the stringlength first (quick check) and then compare the
    content.            */
-int make_win32_path_UTF8_2_wchar(
+static int make_win32_path_UTF8_2_wchar(
 	char **pszUCS,
-	const char *pszUTF,
-	BOOL *pBIsRawPath
+	const char *pszUTF
 ) {
 	if(!g_pWin32ConvUTF8Cache)
 		Win32ConvInitCache();
@@ -460,12 +412,8 @@ int make_win32_path_UTF8_2_wchar(
 	   path syntax */
 	int nRet=UTF8_2_wchar(pszUCS, pszUTF);
 
-#ifdef USE_WIN32_32KPATHCONVERSION
 	// Add \\?\ to support 32K long filepaths.
-	*pszUCS=make_wchar_win32_path(*pszUCS, pBIsRawPath);
-#else
-	if(pBIsRawPath) *pBIsRawPath=FALSE;
-#endif
+	*pszUCS=make_wchar_win32_path(*pszUCS);
 
 	// Populate cache.
 	g_pWin32ConvUCS2Cache=sm_check_pool_memory_size(g_pWin32ConvUCS2Cache,
@@ -546,26 +494,6 @@ int fcntl(int fd, int cmd)
 	return 0;
 }
 
-int chown(const char *k, uid_t, gid_t)
-{
-	return 0;
-}
-
-int lchown(const char *k, uid_t, gid_t)
-{
-	return 0;
-}
-
-long int random(void)
-{
-	return rand();
-}
-
-void srandom(unsigned int seed)
-{
-	srand(seed);
-}
-
 // Convert from Windows concept of time to Unix concept of time.
 void cvt_utime_to_ftime(const time_t &time, FILETIME &wintime)
 {
@@ -1010,11 +938,6 @@ void sleep(int sec)
 	Sleep(sec*1000);
 }
 
-int geteuid(void)
-{
-	return 0;
-}
-
 static int system_error(void)
 {
 	errno=ENOSYS;
@@ -1052,44 +975,6 @@ int strncasecmp(const char *s1, const char *s2, int len)
 	return (ch1-ch2);
 }
 
-int gettimeofday(struct timeval *tv, struct timezone *)
-{
-	SYSTEMTIME now;
-	FILETIME tmp;
-
-	GetSystemTime(&now);
-
-	if(!tv)
-	{
-		errno=EINVAL;
-		return -1;
-	}
-	if(!SystemTimeToFileTime(&now, &tmp))
-	{
-		errno=b_errno_win32;
-		return -1;
-	}
-
-	int64_t _100nsec=tmp.dwHighDateTime;
-	_100nsec<<=32;
-	_100nsec|=tmp.dwLowDateTime;
-	_100nsec-=WIN32_FILETIME_ADJUST;
-
-	tv->tv_sec=(long)(_100nsec / 10000000);
-	tv->tv_usec=(long)((_100nsec % 10000000)/10);
-	return 0;
-
-}
-
-// For apcupsd this is in src/lib/wincompat.c.
-extern "C" void syslog(int type, const char *fmt, ...)
-{
-}
-
-void closelog()
-{
-}
-
 struct passwd *getpwuid(uid_t)
 {
 	return NULL;
@@ -1253,11 +1138,6 @@ err:
 	return NULL;
 }
 
-void init_stack_dump(void)
-{
-}
-
-
 long pathconf(const char *path, int name)
 {
 	switch(name)
@@ -1448,69 +1328,6 @@ char *win32_getcwd(char *buf, int maxlen)
 	return buf;
 }
 
-char *win32_cgets(char* buffer, int len)
-{
-	/* We use console ReadConsoleA / ReadConsoleW to be able to read
-	   unicode from the win32 console and fallback if seomething fails. */
-
-	HANDLE hIn=GetStdHandle (STD_INPUT_HANDLE);
-	if(hIn
-	  && (hIn!=INVALID_HANDLE_VALUE))
-	{
-		DWORD dwRead;
-		wchar_t wszBuf[1024];
-		char  szBuf[1024];
-
-		// NT and unicode conversion.
-		if(ReadConsoleW(hIn, wszBuf, 1024, &dwRead, NULL))
-		{
-			// Null terminate at end.
-			if(wszBuf[dwRead-1]==L'\n')
-			{
-				wszBuf[dwRead-1]=L'\0';
-				dwRead--;
-			}
-
-			if(wszBuf[dwRead-1]==L'\r')
-			{
-				wszBuf[dwRead-1]=L'\0';
-				dwRead--;
-			}
-
-			wchar_2_UTF8(buffer, wszBuf, len);
-			return buffer;
-		}
-
-		// Win 9x and unicode conversion.
-		if(ReadConsoleA(hIn, szBuf, 1024, &dwRead, NULL))
-		{
-			// Null terminate at end.
-			if(szBuf[dwRead-1]==L'\n')
-			{
-				szBuf[dwRead-1]=L'\0';
-				dwRead--;
-			}
-
-			if(szBuf[dwRead-1]==L'\r')
-			{
-				szBuf[dwRead-1]=L'\0';
-				dwRead--;
-			}
-
-			// Convert from ansii to wchar_t.
-			p_MultiByteToWideChar(GetConsoleCP(),
-				0, szBuf, -1, wszBuf, 1024);
-			// Convert from wchar_t to UTF-8.
-			if(wchar_2_UTF8(buffer, wszBuf, len))
-				return buffer;
-		}
-	}
-
-	// Fallback.
-	if(fgets(buffer, len, stdin)) return buffer;
-	return NULL;
-}
-
 int win32_unlink(const char *filename)
 {
 	int nRetCode=-1;
@@ -1548,256 +1365,6 @@ int win32_unlink(const char *filename)
 	return nRetCode;
 }
 
-
-#include "mswinver.h"
-
-char WIN_VERSION_LONG[64];
-char WIN_VERSION[32];
-char WIN_RAWVERSION[32];
-
-class winver
-{
-public:
-	winver(void);
-};
-
-static winver INIT; // cause constructor to be called before main()
-
-winver::winver(void)
-{
-	const char *version="";
-	const char *platform="";
-	OSVERSIONINFO osvinfo;
-	osvinfo.dwOSVersionInfoSize=sizeof(osvinfo);
-
-	// Get the current OS version.
-	if(!GetVersionEx(&osvinfo))
-	{
-		version = "Unknown";
-		platform = "Unknown";
-	}
-	const int ver =_mkversion(osvinfo.dwPlatformId,
-			osvinfo.dwMajorVersion,
-			osvinfo.dwMinorVersion);
-	snprintf(WIN_RAWVERSION, sizeof(WIN_RAWVERSION), "Windows %#08x", ver);
-	switch(ver)
-	{
-		case MS_WINDOWS_95: (version="Windows 95"); break;
-		case MS_WINDOWS_98: (version="Windows 98"); break;
-		case MS_WINDOWS_ME: (version="Windows ME"); break;
-		case MS_WINDOWS_NT4:(version="Windows NT 4.0");
-				platform = "NT"; break;
-		case MS_WINDOWS_2K: (version="Windows 2000");
-				platform = "NT"; break;
-		case MS_WINDOWS_XP: (version="Windows XP");
-				platform = "NT"; break;
-		case MS_WINDOWS_S2003: (version =  "Windows Server 2003");
-				platform = "NT"; break;
-		default: version = WIN_RAWVERSION; break;
-	}
-
-	snprintf(WIN_VERSION_LONG, sizeof(WIN_VERSION_LONG), "%s", version);
-	snprintf(WIN_VERSION, sizeof(WIN_VERSION), "%s %lu.%lu.%lu",
-			platform, osvinfo.dwMajorVersion,
-			osvinfo.dwMinorVersion, osvinfo.dwBuildNumber);
-}
-
-VOID WriteToPipe(VOID);
-VOID ReadFromPipe(VOID);
-VOID ErrorExit(LPCSTR);
-VOID ErrMsg(LPTSTR, BOOL);
-
-static int dwAltNameLength_ok(DWORD dwAltNameLength)
-{
-	return dwAltNameLength>0 && dwAltNameLength<MAX_PATH_UTF8;
-}
-
-/* Extracts the executable or script name from the first string in
-   cmdline.
-
-   If the name contains blanks then it must be quoted with double quotes,
-   otherwise quotes are optional.  If the name contains blanks then it
-   will be converted to a short name.
-
-   The optional quotes will be removed.  The result is copied to a malloc'ed
-   buffer and returned through the pexe argument.  The pargs parameter is set
-   to the address of the character in cmdline located after the name.
-
-   The malloc'ed buffer returned in *pexe must be freed by the caller.  */
-bool GetApplicationName(const char *cmdline, char **pexe, const char **pargs)
-{
-	// Start of executable name in cmdline.
-	const char *pExeStart=NULL;
-	// Character after executable name (separator).
-	const char *pExeEnd=NULL;
-
-	// Character after last path separator.
-	const char *pBasename=NULL;
-	// Period at start of extension.
-	const char *pExtension=NULL;
-
-	const char *current=cmdline;
-
-	bool bQuoted=false;
-
-	// Skip initial whitespace.
-	while(*current==' ' || *current=='\t') current++;
-
-	// Calculate start of name and determine if quoted.
-
-	if(*current=='"')
-	{
-		pExeStart=++current;
-		bQuoted=true;
-	}
-	else
-	{
-		pExeStart=current;
-		bQuoted=false;
-	}
-
-	*pargs=NULL;
-	*pexe=NULL;
-
-	/* Scan command line looking for path separators (/ and \\) and the
-	   terminator, either a quote or a blank.  The location of the
-	   extension is also noted.  */
-	for( ; *current!='\0'; current++)
-	{
-		if(*current=='.')
-			pExtension=current;
-		else if(IsPathSeparator(*current) && current[1]!='\0')
-		{
-			pBasename=&current[1];
-			pExtension=NULL;
-		}
-
-		// Check for terminator, either quote or blank.
-		if(bQuoted)
-		{
-			if(*current!='"') continue;
-		}
-		else
-		{
-			if(*current!=' ') continue;
-		}
-
-		/* Hit terminator, remember end of name (address of terminator)
-		   and start of arguments. */
-		pExeEnd=current;
-
-		if(bQuoted && *current=='"')
-			*pargs=&current[1];
-		else
-			*pargs=current;
-		break;
-	}
-
-	if(!pBasename) pBasename=pExeStart;
-
-	if(!pExeEnd) pExeEnd=current;
-
-	if(!*pargs) *pargs=current;
-
-	bool bHasPathSeparators=pExeStart!=pBasename;
-
-	// We have pointers to all the useful parts of the name.
-
-	// Default extensions in the order cmd.exe uses to search.
-
-	static const char ExtensionList[][5]={".com", ".exe", ".bat", ".cmd"};
-	DWORD dwBasePathLength=pExeEnd-pExeStart;
-
-	DWORD dwAltNameLength=0;
-	char *pPathname=(char *)alloca(MAX_PATH_UTF8+1);
-	char *pAltPathname=(char *)alloca(MAX_PATH_UTF8+1);
-
-	pPathname[MAX_PATH_UTF8]='\0';
-	pAltPathname[MAX_PATH_UTF8]='\0';
-
-	memcpy(pPathname, pExeStart, dwBasePathLength);
-	pPathname[dwBasePathLength]='\0';
-
-	if(!pExtension)
-	{
-		// Try appending extensions.
-		for(int index=0;
-		  index<(int)(sizeof(ExtensionList)/sizeof(ExtensionList[0]));
-		  index++)
-		{
-			if(!bHasPathSeparators)
-			{
-				// There are no path separators, search in the
-				// standard locations
-				dwAltNameLength=SearchPath(NULL, pPathname,
-				  ExtensionList[index], MAX_PATH_UTF8,
-				  pAltPathname, NULL);
-				if(dwAltNameLength_ok(dwAltNameLength))
-				{
-					memcpy(pPathname, pAltPathname,
-						dwAltNameLength);
-					pPathname[dwAltNameLength]='\0';
-					break;
-				}
-			}
-			else
-			{
-				snprintf(&pPathname[dwBasePathLength],
-					MAX_PATH_UTF8-dwBasePathLength,
-					"%s", ExtensionList[index]);
-				if(GetFileAttributes(pPathname)
-				  !=INVALID_FILE_ATTRIBUTES)
-					break;
-				pPathname[dwBasePathLength]='\0';
-			}
-		}
-	}
-	else if(!bHasPathSeparators)
-	{
-		// There are no path separators, search in the standard
-		// locations.
-		dwAltNameLength=SearchPath(NULL, pPathname,
-			NULL, MAX_PATH_UTF8, pAltPathname, NULL);
-		if(dwAltNameLength_ok(dwAltNameLength))
-		{
-			memcpy(pPathname, pAltPathname, dwAltNameLength);
-			pPathname[dwAltNameLength] = '\0';
-		}
-	}
-
-	if(strchr(pPathname, ' '))
-	{
-		dwAltNameLength=GetShortPathName(pPathname,
-			pAltPathname, MAX_PATH_UTF8);
-
-		if(dwAltNameLength_ok(dwAltNameLength))
-		{
-			*pexe=(char *)malloc(dwAltNameLength+1);
-			if(!*pexe) return false;
-			memcpy(*pexe, pAltPathname, dwAltNameLength+1);
-		}
-	}
-
-	if(!*pexe)
-	{
-		DWORD dwPathnameLength=strlen(pPathname);
-		*pexe=(char *)malloc(dwPathnameLength+1);
-		if(!*pexe) return false;
-		memcpy(*pexe, pPathname, dwPathnameLength+1);
-	}
-
-	return true;
-}
-
-void ErrorExit(LPCSTR lpszMessage)
-{
-}
-
-// syslog function, added by Nicolas Boichat.
-void openlog(const char *ident, int option, int facility)
-{
-}
-
 static pid_t do_forkchild(struct fzp **sin,
 	struct fzp **sout, struct fzp **serr,
 	const char *path, char * const argv[], int do_wait)
@@ -2038,7 +1605,7 @@ end:
 	return ret;
 }
 
-char *get_fixed_drives(void)
+static char *get_drives(uint64_t type)
 {
 	static char ret[256]="";
 	size_t r=0;
@@ -2059,7 +1626,7 @@ char *get_fixed_drives(void)
 		int l;
 		char u[8];
 		l=wchar_2_UTF8(u, (const wchar_t *)drive, sizeof(u));
-		if(GetDriveTypeW((const wchar_t *)drive)==DRIVE_FIXED)
+		if(GetDriveTypeW((const wchar_t *)drive)==type)
 		{
 			if(isalpha(*u))
 				ret[r++]=toupper(*u);
@@ -2069,3 +1636,13 @@ char *get_fixed_drives(void)
 
 	return ret;
 }
+
+char *get_fixed_drives(void)
+{
+	return get_drives(DRIVE_FIXED);
+}
+
+char *get_remote_drives(void)
+{
+	return get_drives(DRIVE_REMOTE);
+}
