@@ -133,20 +133,16 @@ static void setup_1_3_0_write_problem(struct asfd *asfd,
 	asfd_assert_write(asfd, &w, -1, CMD_GEN, "extra_comms_begin ok");
 }
 
-static void common_confs(struct conf **cconfs, const char *version,
-	enum protocol protocol)
+static void common_confs(struct conf **cconfs, const char *version)
 {
 	set_string(cconfs[OPT_PEER_VERSION], version);
 	set_string(cconfs[OPT_DIRECTORY], BASE "/spool");
 	set_string(cconfs[OPT_CNAME], TESTCLIENT);
 	set_string(cconfs[OPT_DEDUP_GROUP], "global");
-	set_protocol(cconfs, protocol);
 }
 
-static const char *get_features(enum protocol protocol, int srestore,
-	const char *version)
+static const char *get_features(int srestore, const char *version)
 {
-	char proto[32]="";
 	char rshash[32]="";
 	int old_version=0;
 	static char features[256]="";
@@ -154,16 +150,10 @@ static const char *get_features(enum protocol protocol, int srestore,
 #ifdef HAVE_BLAKE2
 	snprintf(rshash, sizeof(rshash), "rshash=blake2:");
 #endif
-	if(protocol==PROTO_AUTO)
-		snprintf(proto, sizeof(proto), "csetproto:");
-	else
-		snprintf(proto, sizeof(proto), "forceproto=%d:",
-			(int)protocol);
-
 	if(version && !strcmp(version, "1.4.40"))
 		old_version=1;
 
-	snprintf(features, sizeof(features), "extra_comms_begin ok:autoupgrade:incexc:orig_client:uname:failover:vss_restore:regex_icase:%s%smsg:%s%sseed:", srestore?"srestore:":"", old_version?"":"counters_json:", proto, rshash);
+	snprintf(features, sizeof(features), "extra_comms_begin ok:autoupgrade:incexc:orig_client:uname:failover:vss_restore:regex_icase:%s%smsg:forceproto=1:%sseed:", srestore?"srestore:":"", old_version?"":"counters_json:", rshash);
 	return features;
 }
 
@@ -172,253 +162,35 @@ static void setup_feature_write_problem(struct asfd *asfd,
 {
 	int r=0; int w=0;
 	const char *features;
-	enum protocol protocol=PROTO_AUTO;
-	common_confs(cconfs, PACKAGE_VERSION, protocol);
+	common_confs(cconfs, PACKAGE_VERSION);
 	asfd_mock_read(asfd, &r, 0, CMD_GEN, "extra_comms_begin");
-	features=get_features(protocol, /*srestore*/0, NULL/*version*/);
+	features=get_features(/*srestore*/0, NULL/*version*/);
 	asfd_assert_write(asfd, &w, -1, CMD_GEN, features);
 }
 
-static void setup_send_features_proto_begin(struct asfd *asfd,
-	struct conf **confs, struct conf **cconfs, enum protocol protocol,
+static void setup_send_features_begin(struct asfd *asfd,
+	struct conf **confs, struct conf **cconfs,
 	int *r, int *w, const char *version, int srestore)
 {
 	const char *features=NULL;
-	common_confs(cconfs, version, protocol);
+	common_confs(cconfs, version);
 	asfd_mock_read(asfd, r, 0, CMD_GEN, "extra_comms_begin");
-	features=get_features(protocol, srestore, version);
+	features=get_features(srestore, version);
 	asfd_assert_write(asfd, w, 0, CMD_GEN, features);
 }
 
-static void setup_send_features_proto_end(struct asfd *asfd, int *r, int *w)
+static void setup_send_features_end(struct asfd *asfd, int *r, int *w)
 {
 	asfd_mock_read(asfd, r, 0, CMD_GEN, "extra_comms_end");
 	asfd_assert_write(asfd, w, 0, CMD_GEN, "extra_comms_end ok");
 }
 
-static void setup_send_features_proto(struct asfd *asfd,
-	struct conf **confs, struct conf **cconfs, enum protocol protocol,
-	const char *version)
-{
-	int r=0; int w=0;
-	setup_send_features_proto_begin(asfd, confs, cconfs, protocol, &r, &w,
-		version, /*srestore*/0);
-	setup_send_features_proto_end(asfd, &r, &w);
-}
-
-static void setup_send_features_proto_auto(struct asfd *asfd,
-	struct conf **confs, struct conf **cconfs)
-{
-	setup_send_features_proto(asfd, confs, cconfs, PROTO_AUTO, PACKAGE_VERSION);
-}
-
-static void setup_send_features_proto_auto_old_client(struct asfd *asfd,
-	struct conf **confs, struct conf **cconfs)
-{
-	setup_send_features_proto(asfd, confs, cconfs, PROTO_AUTO, "1.4.40");
-}
-
-static void setup_send_features_proto1(struct asfd *asfd,
-	struct conf **confs, struct conf **cconfs)
-{
-	setup_send_features_proto(asfd, confs, cconfs, PROTO_1, PACKAGE_VERSION);
-}
-
-static void setup_send_features_proto1_old_client(struct asfd *asfd,
-	struct conf **confs, struct conf **cconfs)
-{
-	setup_send_features_proto(asfd, confs, cconfs, PROTO_1, "1.4.40");
-}
-
-static void setup_send_features_proto2(struct asfd *asfd,
-	struct conf **confs, struct conf **cconfs)
-{
-	setup_send_features_proto(asfd, confs, cconfs, PROTO_2, PACKAGE_VERSION);
-}
-
-static void setup_send_features_proto2_old_client(struct asfd *asfd,
-	struct conf **confs, struct conf **cconfs)
-{
-	setup_send_features_proto(asfd, confs, cconfs, PROTO_2, "1.4.40");
-}
-
-static void setup_send_features_proto_auto_auto(struct asfd *asfd,
-	struct conf **confs, struct conf **cconfs)
-{
-	int r=0; int w=0;
-	setup_send_features_proto_begin(asfd, confs, cconfs,
-		PROTO_AUTO, &r, &w, PACKAGE_VERSION, /*srestore*/0);
-	asfd_mock_read(asfd, &r, 0, CMD_GEN, "protocol=0");
-	asfd_assert_write(asfd, &w, 0, CMD_ERROR,
-		"Client is trying to use protocol=0, which is unknown\n");
-}
-
-static void setup_send_features_proto_proto(struct asfd *asfd,
-	struct conf **confs, struct conf **cconfs, const char *version,
-	enum protocol protocol_server, enum protocol protocol_client)
-{
-	int r=0; int w=0;
-	char cprotocol[16]="";
-	snprintf(cprotocol, sizeof(cprotocol),
-		"protocol=%d", (int)protocol_client);
-	setup_send_features_proto_begin(asfd, confs, cconfs,
-		protocol_server, &r, &w, version, /*srestore*/0);
-	asfd_mock_read(asfd, &r, 0, CMD_GEN, cprotocol);
-	setup_send_features_proto_end(asfd, &r, &w);
-}
-
-static void setup_send_features_proto_auto_1(struct asfd *asfd,
-	struct conf **confs, struct conf **cconfs)
-{
-	setup_send_features_proto_proto(asfd, confs, cconfs, PACKAGE_VERSION,
-		PROTO_AUTO, PROTO_1);
-}
-
-static void setup_send_features_proto_auto_1_old_client(struct asfd *asfd,
-	struct conf **confs, struct conf **cconfs)
-{
-	setup_send_features_proto_proto(asfd, confs, cconfs, "1.4.40",
-		PROTO_AUTO, PROTO_1);
-}
-
-static void setup_send_features_proto_auto_2(struct asfd *asfd,
-	struct conf **confs, struct conf **cconfs)
-{
-	setup_send_features_proto_proto(asfd, confs, cconfs, PACKAGE_VERSION,
-		PROTO_AUTO, PROTO_2);
-}
-
-static void setup_send_features_proto_auto_2_old_client(struct asfd *asfd,
-	struct conf **confs, struct conf **cconfs)
-{
-	setup_send_features_proto_proto(asfd, confs, cconfs, "1.4.40",
-		PROTO_AUTO, PROTO_2);
-}
-
-static void setup_send_features_proto_x_y(struct asfd *asfd,
-	struct conf **confs, struct conf **cconfs,
-	enum protocol s_protocol, enum protocol c_protocol)
-{
-	int r=0; int w=0;
-	char msg[256]="";
-	char cliproto[16]="";
-	snprintf(cliproto, sizeof(cliproto), "protocol=%d", (int)c_protocol);
-	setup_send_features_proto_begin(asfd, confs, cconfs,
-		s_protocol, &r, &w, PACKAGE_VERSION, /*srestore*/0);
-	asfd_mock_read(asfd, &r, 0, CMD_GEN, cliproto);
-	snprintf(msg, sizeof(msg), "Client is trying to use protocol=%d but server is set to protocol=%d\n", (int)c_protocol, (int)s_protocol);
-	asfd_assert_write(asfd, &w, 0, CMD_ERROR, msg);
-}
-
-static void setup_send_features_proto_1_auto(struct asfd *asfd,
-	struct conf **confs, struct conf **cconfs)
-{
-	setup_send_features_proto_x_y(asfd, confs, cconfs,
-		PROTO_1, PROTO_AUTO);
-}
-
-static void setup_send_features_proto_2_auto(struct asfd *asfd,
-	struct conf **confs, struct conf **cconfs)
-{
-	setup_send_features_proto_x_y(asfd, confs, cconfs,
-		PROTO_2, PROTO_AUTO);
-}
-
-static void setup_send_features_proto_1_2(struct asfd *asfd,
-	struct conf **confs, struct conf **cconfs)
-{
-	setup_send_features_proto_x_y(asfd, confs, cconfs,
-		PROTO_1, PROTO_2);
-}
-
-static void setup_send_features_proto_2_1(struct asfd *asfd,
-	struct conf **confs, struct conf **cconfs)
-{
-	setup_send_features_proto_x_y(asfd, confs, cconfs,
-		PROTO_2, PROTO_1);
-}
-
-static void setup_send_features_proto_1_1(struct asfd *asfd,
-	struct conf **confs, struct conf **cconfs)
-{
-	setup_send_features_proto_proto(asfd, confs, cconfs, PACKAGE_VERSION,
-		PROTO_1, PROTO_1);
-}
-
-static void setup_send_features_proto_2_2(struct asfd *asfd,
-	struct conf **confs, struct conf **cconfs)
-{
-	setup_send_features_proto_proto(asfd, confs, cconfs, PACKAGE_VERSION,
-		PROTO_2, PROTO_2);
-}
-
-static void checks_proto_auto_no_features_from_client(
-	struct conf **confs, struct conf **cconfs, const char *incexc,
-	int srestore)
-{
-	// Server is PROTO_AUTO, client said nothing.
-	fail_unless(get_protocol(confs)==PROTO_1);
-}
-
-static void checks_proto_auto_no_features_from_client_old_client(
-	struct conf **confs, struct conf **cconfs, const char *incexc,
-	int srestore)
-{
-	// Server is PROTO_AUTO, client said nothing. Client is old version,
-	// so should be forced to PROTO_1.
-	fail_unless(get_protocol(cconfs)==PROTO_1);
-	fail_unless(get_protocol(confs)==PROTO_1);
-}
-
-static void checks_proto1_no_features_from_client(
-	struct conf **confs, struct conf **cconfs, const char *incexc,
-	int srestore)
-{
-	// Server is PROTO_1, client said nothing.
-	fail_unless(get_protocol(confs)==PROTO_AUTO);
-}
-
-static void checks_proto1_no_features_from_client_old_client(
-	struct conf **confs, struct conf **cconfs, const char *incexc,
-	int srestore)
-{
-	// Server is PROTO_1, client said nothing. Client is old version.
-	fail_unless(get_protocol(confs)==PROTO_AUTO);
-}
-
-static void checks_proto2_no_features_from_client(
-	struct conf **confs, struct conf **cconfs, const char *incexc,
-	int srestore)
-{
-	// Server is PROTO_2, client said nothing.
-	fail_unless(get_protocol(confs)==PROTO_AUTO);
-}
-
-static void checks_proto_auto_1(
-	struct conf **confs, struct conf **cconfs, const char *incexc,
-	int srestore)
-{
-	// Server is PROTO_AUTO, client said PROTO_1
-	fail_unless(get_protocol(confs)==PROTO_1);
-	// We did not set OPT_RSHASH. It should be set to RSHASH_MD4 for us.
-	fail_unless(get_e_rshash(confs[OPT_RSHASH])==RSHASH_MD4);
-	fail_unless(get_e_rshash(cconfs[OPT_RSHASH])==RSHASH_MD4);
-}
-
-static void checks_proto_auto_2(
-	struct conf **confs, struct conf **cconfs, const char *incexc,
-	int srestore)
-{
-	// Server is PROTO_AUTO, client said PROTO_2
-	fail_unless(get_protocol(confs)==PROTO_2);
-}
-
 static void setup_unexpected_cmd_feature(struct asfd *asfd,
 	struct conf **confs, struct conf **cconfs)
 {
 	int r=0; int w=0;
-	setup_send_features_proto_begin(asfd, confs, cconfs,
-		PROTO_AUTO, &r, &w, PACKAGE_VERSION, /*srestore*/0);
+	setup_send_features_begin(asfd, confs, cconfs,
+		&r, &w, PACKAGE_VERSION, /*srestore*/0);
 	asfd_mock_read(asfd, &r, 0, CMD_FILE, "blah");
 }
 
@@ -427,10 +199,10 @@ static void setup_simple(struct asfd *asfd,
 	int srestore)
 {
 	int r=0; int w=0;
-	setup_send_features_proto_begin(asfd, confs, cconfs,
-		PROTO_AUTO, &r, &w, PACKAGE_VERSION, srestore);
+	setup_send_features_begin(asfd, confs, cconfs,
+		&r, &w, PACKAGE_VERSION, srestore);
 	asfd_mock_read(asfd, &r, 0, CMD_GEN, feature);
-	setup_send_features_proto_end(asfd, &r, &w);
+	setup_send_features_end(asfd, &r, &w);
 }
 
 static void setup_autoupgrade_no_os(struct asfd *asfd,
@@ -443,12 +215,12 @@ static void setup_autoupgrade(struct asfd *asfd,
 	struct conf **confs, struct conf **cconfs)
 {
 	int r=0; int w=0;
-	setup_send_features_proto_begin(asfd, confs, cconfs,
-		PROTO_AUTO, &r, &w, PACKAGE_VERSION, /*srestore*/0);
+	setup_send_features_begin(asfd, confs, cconfs,
+		&r, &w, PACKAGE_VERSION, /*srestore*/0);
 	asfd_mock_read(asfd, &r, 0, CMD_GEN, "autoupgrade:some_os");
 	// Server does not have an autoupgrade_dir set.
 	asfd_assert_write(asfd, &w, 0, CMD_GEN, "do not autoupgrade");
-	setup_send_features_proto_end(asfd, &r, &w);
+	setup_send_features_end(asfd, &r, &w);
 }
 
 static void setup_rshash_blake2(struct asfd *asfd,
@@ -458,8 +230,8 @@ static void setup_rshash_blake2(struct asfd *asfd,
 	setup_simple(asfd, confs, cconfs, "rshash=blake2", /*srestore*/0);
 #else
 	int r=0; int w=0;
-	setup_send_features_proto_begin(asfd, confs, cconfs,
-		PROTO_AUTO, &r, &w, PACKAGE_VERSION, /*srestore*/0);
+	setup_send_features_begin(asfd, confs, cconfs,
+		&r, &w, PACKAGE_VERSION, /*srestore*/0);
 	asfd_mock_read(asfd, &r, 0, CMD_GEN, "rshash=blake2");
 #endif
 }
@@ -529,8 +301,8 @@ static void setup_unexpected_feature(struct asfd *asfd,
 	struct conf **confs, struct conf **cconfs)
 {
 	int r=0; int w=0;
-	setup_send_features_proto_begin(asfd, confs, cconfs,
-		PROTO_AUTO, &r, &w, PACKAGE_VERSION, /*srestore*/0);
+	setup_send_features_begin(asfd, confs, cconfs,
+		&r, &w, PACKAGE_VERSION, /*srestore*/0);
 	asfd_mock_read(asfd, &r, 0, CMD_GEN, "somenonsense");
 }
 
@@ -555,7 +327,7 @@ static void setup_srestore(struct asfd *asfd,
 {
 	struct strlist *strlist=NULL;
 	build_file(SRESTORE_FILE, "");
-	setup_send_features_proto_begin(asfd, confs, cconfs, PROTO_AUTO,
+	setup_send_features_begin(asfd, confs, cconfs,
 		r, w, PACKAGE_VERSION, /*srestore*/1);
 
 	strlist_add(&strlist, "/some/path", 1);
@@ -575,7 +347,7 @@ static void setup_srestore_ok(struct asfd *asfd,
 	int r=0; int w=0;
 	setup_srestore(asfd, confs, cconfs, &r, &w);
 	asfd_mock_read(asfd, &r, 0, CMD_GEN, "srestore end ok");
-	setup_send_features_proto_end(asfd, &r, &w);
+	setup_send_features_end(asfd, &r, &w);
 }
 
 static void checks_srestore_ok(struct conf **confs, struct conf **cconfs,
@@ -602,7 +374,7 @@ static void setup_sincexc_ok(struct asfd *asfd,
 	struct conf **confs, struct conf **cconfs)
 {
 	int r=0; int w=0;
-	setup_send_features_proto_begin(asfd, confs, cconfs, PROTO_AUTO,
+	setup_send_features_begin(asfd, confs, cconfs,
 		&r, &w, PACKAGE_VERSION, /*srestore*/0);
 	asfd_mock_read(asfd, &r, 0, CMD_GEN, "sincexc ok");
 	asfd_assert_write(asfd, &w, 0, CMD_GEN, "cross_all_filesystems = 0");
@@ -622,21 +394,21 @@ static void setup_sincexc_ok(struct asfd *asfd,
 	asfd_assert_write(asfd, &w, 0, CMD_GEN, "regex_case_insensitive = 0");
 	asfd_assert_write(asfd, &w, 0, CMD_GEN, "sincexc end");
 	asfd_mock_read(asfd, &r, 0, CMD_GEN, "sincexc end ok");
-	setup_send_features_proto_end(asfd, &r, &w);
+	setup_send_features_end(asfd, &r, &w);
 }
 
 static void setup_incexc(struct asfd *asfd,
 	struct conf **confs, struct conf **cconfs)
 {
 	int r=0; int w=0;
-	setup_send_features_proto_begin(asfd, confs, cconfs, PROTO_AUTO,
+	setup_send_features_begin(asfd, confs, cconfs,
 		&r, &w, PACKAGE_VERSION, /*srestore*/0);
 	asfd_mock_read(asfd, &r, 0, CMD_GEN, "incexc");
 	asfd_assert_write(asfd, &w, 0, CMD_GEN, "incexc ok");
 	asfd_mock_read(asfd, &r, 0, CMD_GEN, "include = /some/path");
 	asfd_mock_read(asfd, &r, 0, CMD_GEN, "incexc end");
 	asfd_assert_write(asfd, &w, 0, CMD_GEN, "incexc end ok");
-	setup_send_features_proto_end(asfd, &r, &w);
+	setup_send_features_end(asfd, &r, &w);
 }
 
 static void checks_incexc(struct conf **confs, struct conf **cconfs,
@@ -651,8 +423,8 @@ static void setup_orig_client_not_existing(struct asfd *asfd,
 {
 	int r=0; int w=0;
 
-	setup_send_features_proto_begin(asfd, confs, cconfs,
-		PROTO_AUTO, &r, &w, PACKAGE_VERSION, /*srestore*/0);
+	setup_send_features_begin(asfd, confs, cconfs,
+		&r, &w, PACKAGE_VERSION, /*srestore*/0);
 	asfd_mock_read(asfd, &r, 0, CMD_GEN, "orig_client=cli2");
 }
 
@@ -660,16 +432,15 @@ static void setup_orig_client(struct asfd *asfd,
 	struct conf **confs, struct conf **cconfs)
 {
 	int r=0; int w=0;
-	enum protocol protocol=PROTO_AUTO;
 
-	common_confs(cconfs, PACKAGE_VERSION, protocol);
+	common_confs(cconfs, PACKAGE_VERSION);
 	set_string(confs[OPT_CLIENTCONFDIR], CLIENTCONFDIR);
 	build_file(CLIENTCONFDIR "/cli2", "restore_client=" TESTCLIENT);
-	setup_send_features_proto_begin(asfd, confs, cconfs,
-		protocol, &r, &w, PACKAGE_VERSION, /*srestore*/0);
+	setup_send_features_begin(asfd, confs, cconfs,
+		&r, &w, PACKAGE_VERSION, /*srestore*/0);
 	asfd_mock_read(asfd, &r, 0, CMD_GEN, "orig_client=cli2");
 	asfd_assert_write(asfd, &w, 0, CMD_GEN, "orig_client ok");
-	setup_send_features_proto_end(asfd, &r, &w);
+	setup_send_features_end(asfd, &r, &w);
 }
 
 static void checks_orig_client(struct conf **confs, struct conf **cconfs,
@@ -687,15 +458,14 @@ static void setup_orig_client_srestore(struct asfd *asfd,
 	struct conf **confs, struct conf **cconfs)
 {
 	int r=0; int w=0;
-	enum protocol protocol=PROTO_AUTO;
 	build_file(SRESTORE_FILE, "overwrite=1");
 	build_file(SRESTORE_FILE_CLI2, "strip=1");
 
-	common_confs(cconfs, PACKAGE_VERSION, protocol);
+	common_confs(cconfs, PACKAGE_VERSION);
 	set_string(confs[OPT_CLIENTCONFDIR], CLIENTCONFDIR);
 	build_file(CLIENTCONFDIR "/cli2", "restore_client=" TESTCLIENT);
-	setup_send_features_proto_begin(asfd, confs, cconfs,
-		protocol, &r, &w, PACKAGE_VERSION, /*srestore*/1);
+	setup_send_features_begin(asfd, confs, cconfs,
+		&r, &w, PACKAGE_VERSION, /*srestore*/1);
 
 	asfd_mock_read(asfd, &r, 0, CMD_GEN, "srestore ok");
 	asfd_assert_write(asfd, &w, 0, CMD_GEN, "overwrite = 1");
@@ -717,7 +487,7 @@ static void setup_orig_client_srestore(struct asfd *asfd,
 	asfd_assert_write(asfd, &w, 0, CMD_GEN, "srestore end");
 	asfd_mock_read(asfd, &r, 0, CMD_GEN, "srestore end ok");
 
-	setup_send_features_proto_end(asfd, &r, &w);
+	setup_send_features_end(asfd, &r, &w);
 }
 
 static void checks_orig_client_srestore(struct conf **confs,
@@ -739,44 +509,6 @@ START_TEST(test_server_extra_comms)
 	run_test(-1, setup_1_3_0_write_problem, NULL);
 	run_test(-1, setup_feature_write_problem, NULL);
 
-	run_test(0, setup_send_features_proto_auto,
-		checks_proto_auto_no_features_from_client);
-	run_test(0, setup_send_features_proto1,
-		checks_proto1_no_features_from_client);
-	run_test(0, setup_send_features_proto2,
-		checks_proto2_no_features_from_client);
-	run_test(0, setup_send_features_proto_auto_1,
-		checks_proto_auto_1);
-	run_test(0, setup_send_features_proto_auto_2,
-		checks_proto_auto_2);
-
-	run_test(0, setup_send_features_proto_auto_old_client,
-		checks_proto_auto_no_features_from_client_old_client);
-	run_test(0, setup_send_features_proto1_old_client,
-		checks_proto1_no_features_from_client_old_client);
-	run_test(-1, setup_send_features_proto2_old_client,
-		NULL);
-	run_test(0, setup_send_features_proto_auto_1_old_client,
-		checks_proto_auto_1);
-	run_test(-1, setup_send_features_proto_auto_2_old_client,
-		NULL);
-
-	run_test(-1, setup_send_features_proto_auto_auto,
-		NULL);
-	run_test(-1, setup_send_features_proto_1_auto,
-		NULL);
-	run_test(-1, setup_send_features_proto_2_auto,
-		NULL);
-	run_test(-1, setup_send_features_proto_1_2,
-		NULL);
-	run_test(-1, setup_send_features_proto_2_1,
-		NULL);
-
-	run_test(0, setup_send_features_proto_1_1,
-		NULL);
-	run_test(0, setup_send_features_proto_2_2,
-		NULL);
-
 	run_test(-1, setup_unexpected_cmd_feature,
 		NULL);
 
